@@ -97,7 +97,7 @@ clearlooks_style_draw_flat_box (DRAW_ARGS)
 
 		cairo_destroy (cr);
 	}
-	else if (CLEARLOOKS_STYLE (style)->style == CL_STYLE_GLOSSY &&
+	else if ((CLEARLOOKS_STYLE (style)->style == CL_STYLE_GLOSSY || CLEARLOOKS_STYLE (style)->style == CL_STYLE_GUMMY) &&
 	         ((DETAIL("checkbutton") || DETAIL("radiobutton")) && state_type == GTK_STATE_PRELIGHT))
 	{
 		/* XXX: Don't draw any check/radiobutton bg in GLOSSY mode. */
@@ -121,13 +121,14 @@ clearlooks_style_draw_shadow (DRAW_ARGS)
 	CHECK_ARGS
 	SANITIZE_SIZE
 
-	if (DETAIL ("entry") && !(widget && widget->parent && GE_IS_TREE_VIEW (widget->parent)))
+	if ((DETAIL ("entry") && !(widget && widget->parent && GE_IS_TREE_VIEW (widget->parent))) ||
+	    (DETAIL ("frame") && ge_is_in_combo_box (widget)))
 	{
 		WidgetParameters params;
 		
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
-		
-		if (widget && (ge_is_in_combo_box(widget) || GE_IS_SPIN_BUTTON (widget)))
+
+		if (widget && (ge_is_in_combo_box (widget) || GE_IS_SPIN_BUTTON (widget)))
 		{
 			width += style->xthickness;
 			if (!params.ltr)
@@ -173,7 +174,7 @@ clearlooks_style_draw_shadow (DRAW_ARGS)
 	{
 		CairoColor *border = (CairoColor*)&colors->shade[5];
 		cairo_rectangle (cr, x+0.5, y+0.5, width-1, height-1);
-		cairo_set_source_rgb (cr, border->r, border->g, border->b);
+		ge_cairo_set_color (cr, border);
 		cairo_set_line_width (cr, 1);
 		cairo_stroke (cr);
 	}
@@ -186,7 +187,7 @@ clearlooks_style_draw_shadow (DRAW_ARGS)
 		frame.gap_x  = -1;
 		frame.border = &colors->shade[5];
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
-		params.corners = CR_CORNER_NONE;
+		params.corners = CR_CORNER_ALL;
 		
 		STYLE_FUNCTION(draw_frame) (cr, colors, &params, &frame, x, y, width, height);
 	}
@@ -203,7 +204,10 @@ clearlooks_style_draw_box_gap (DRAW_ARGS,
 	ClearlooksStyle  *clearlooks_style = CLEARLOOKS_STYLE (style);
 	ClearlooksColors *colors = &clearlooks_style->colors;
 	cairo_t          *cr;
-	
+
+	CHECK_ARGS
+	SANITIZE_SIZE
+
 	cr = ge_gdk_drawable_to_cairo (window, area);
 
 	if (DETAIL ("notebook"))
@@ -219,9 +223,82 @@ clearlooks_style_draw_box_gap (DRAW_ARGS,
 		
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
 
-		params.corners = CR_CORNER_NONE;
+		/* Modified from Aurora Engine
+		*** 
+		We need to fix the clip problem on first tab and rounded corners
+		Last Active tab could be buggied if the tabs cover more space then the notebook width
+		***
+		*/
+		int current_page = gtk_notebook_get_current_page ((GtkNotebook *) widget);
+		int num_pages = gtk_notebook_get_n_pages ((GtkNotebook *) widget);
+
+		if (frame.gap_side == CL_GAP_TOP) {
+			if ((current_page == 0) && (num_pages - 1 == 0)) {
+				params.corners = CR_CORNER_BOTTOMRIGHT | CR_CORNER_BOTTOMLEFT;
+			}
+			else if (current_page == 0) {
+				params.corners = CR_CORNER_BOTTOMRIGHT | CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPRIGHT;
+			}
+			else if (current_page == num_pages - 1) {
+				params.corners = CR_CORNER_BOTTOMRIGHT | CR_CORNER_BOTTOMLEFT;
+				/* params.corners = CR_CORNER_BOTTOMRIGHT | CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPLEFT; */
+			}
+			else {
+				params.corners = CR_CORNER_BOTTOMRIGHT | CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPRIGHT;
+				/* params.corners = CR_CORNER_ALL; */
+			}
+		}
+		else if (frame.gap_side == CL_GAP_BOTTOM) {
+			if ((current_page == 0) && (num_pages - 1 == 0)) {
+				params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT;
+			}
+			else if (current_page == 0) {
+				params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMRIGHT;
+			}
+			else if (current_page == num_pages - 1) {
+				params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT;
+				/* params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMLEFT; */
+			}
+			else {
+				params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMRIGHT;
+				/* params.corners = CR_CORNER_ALL; */
+			}
+		}
+		else if (frame.gap_side == CL_GAP_LEFT) {
+			if ((current_page == 0) && (num_pages - 1 == 0)) {
+				params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_BOTTOMRIGHT;
+			}
+			else if (current_page == 0) {
+				params.corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPRIGHT | CR_CORNER_BOTTOMRIGHT;
+			}
+			else if (current_page == num_pages - 1) {
+				params.corners = CR_CORNER_BOTTOMRIGHT | CR_CORNER_TOPRIGHT;
+				/* params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMRIGHT; */
+			}
+			else {
+				params.corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPRIGHT | CR_CORNER_BOTTOMRIGHT;
+				/* params.corners = CR_CORNER_ALL; */
+			}
+		}
+		else {
+			if ((current_page == 0) && (num_pages - 1 == 0)) {
+				params.corners = CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMLEFT;
+			}
+			else if (current_page == 0) {
+				params.corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMRIGHT;
+			}
+			else if (current_page == num_pages - 1) {
+				params.corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPLEFT;
+				/* params.corners = CR_CORNER_TOPRIGHT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMLEFT; */
+			}
+			else {
+				params.corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMRIGHT;
+				/* params.corners = CR_CORNER_ALL; */
+			}
+		}
+
 		/* Fill the background with bg[NORMAL] */
-		cairo_rectangle (cr, x, y, width, height);
+		ge_cairo_rounded_rectangle (cr, x, y, width, height, params.radius, params.corners);
 		ge_cairo_set_color (cr, &colors->bg[GTK_STATE_NORMAL]);
 		cairo_fill (cr);
 		
@@ -246,6 +323,9 @@ clearlooks_style_draw_extension (DRAW_ARGS, GtkPositionType gap_side)
 	ClearlooksColors *colors = &clearlooks_style->colors;
 	cairo_t          *cr;
 
+	CHECK_ARGS
+	SANITIZE_SIZE
+
 	cr = ge_gdk_drawable_to_cairo (window, area);
 	
 	if (DETAIL ("tab"))
@@ -453,6 +533,7 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		else
 		{
 			params.corners    = CR_CORNER_ALL;
+			/* if (!(ge_is_combo_box (widget, FALSE))) */
 			params.enable_glow = TRUE;
 		}		
 	
@@ -671,6 +752,8 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		GtkBorder indicator_spacing;
 		
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
+		
+		params.enable_glow = TRUE;
 
 		ge_option_menu_get_props (widget, &indicator_size, &indicator_spacing);
 		
@@ -704,7 +787,12 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		WidgetParameters    params;
 		ScrollBarParameters scrollbar;
 		ScrollBarStepperParameters stepper;
-		GdkRectangle this_rectangle = { x, y, width, height };
+		GdkRectangle this_rectangle;
+		
+		this_rectangle.x = x;
+		this_rectangle.y = y;
+		this_rectangle.width  = width;
+		this_rectangle.height = height;
 		
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
 		params.corners = CR_CORNER_NONE;
@@ -788,13 +876,14 @@ clearlooks_style_draw_slider (DRAW_ARGS, GtkOrientation orientation)
 		scrollbar.horizontal = (orientation == GTK_ORIENTATION_HORIZONTAL);
 		scrollbar.junction   = clearlooks_scrollbar_get_junction (widget);
 
-		if (clearlooks_style->style == CL_STYLE_GLOSSY) /* XXX! */
+		if (clearlooks_style->style == CL_STYLE_GLOSSY || clearlooks_style->style == CL_STYLE_GUMMY)
 		{
-			scrollbar.color = colors->bg[CL_STATE_NORMAL];
-			ge_shade_color (&scrollbar.color, 0.5, &scrollbar.color);
+			scrollbar.color = colors->spot[1];
 			scrollbar.has_color = TRUE;
 		}
-		else if (clearlooks_style->has_scrollbar_color)
+
+		/* Set scrollbar color also for Glossy */
+		if (clearlooks_style->has_scrollbar_color)
 		{
 			ge_gdk_color_to_cairo (&clearlooks_style->scrollbar_color, &scrollbar.color);
 			scrollbar.has_color = TRUE;
@@ -820,6 +909,9 @@ clearlooks_style_draw_option (DRAW_ARGS)
 	WidgetParameters params;
 	CheckboxParameters checkbox;
 	
+	CHECK_ARGS
+	SANITIZE_SIZE
+
 	cairo_t *cr;
 	cr = ge_gdk_drawable_to_cairo (window, area);
 	colors = &clearlooks_style->colors;
@@ -840,9 +932,11 @@ clearlooks_style_draw_check (DRAW_ARGS)
 	ClearlooksStyle *clearlooks_style = CLEARLOOKS_STYLE (style);
 	WidgetParameters params;
 	CheckboxParameters checkbox;
-		
-
 	cairo_t *cr;
+
+	CHECK_ARGS
+	SANITIZE_SIZE
+
 	cr = ge_gdk_drawable_to_cairo (window, area);
 	
 	clearlooks_set_widget_parameters (widget, style, state_type, &params);
@@ -876,12 +970,13 @@ clearlooks_style_draw_vline                      (GtkStyle               *style,
 	SeparatorParameters separator = { FALSE };
 	cairo_t *cr;
 
-	colors = &clearlooks_style->colors;
+	CHECK_ARGS
 
+	colors = &clearlooks_style->colors;
 
 	cr = ge_gdk_drawable_to_cairo (window, area);
 	
-	STYLE_FUNCTION(draw_separator) (cr, colors, NULL, &separator,
+	STYLE_FUNCTION(draw_separator) (cr, &colors->shade[3], NULL, &separator,
 	                           x, y1, 2, y2-y1);
 	
 	cairo_destroy (cr);
@@ -903,13 +998,15 @@ clearlooks_style_draw_hline                      (GtkStyle               *style,
 	cairo_t *cr;
 	SeparatorParameters separator;
 
+	CHECK_ARGS
+
 	colors = &clearlooks_style->colors;
 
 	cr = ge_gdk_drawable_to_cairo (window, area);
 	
 	separator.horizontal = TRUE;
 	
-	STYLE_FUNCTION(draw_separator) (cr, colors, NULL, &separator,
+	STYLE_FUNCTION(draw_separator) (cr, &colors->shade[3], NULL, &separator,
 	                           x1, y, x2-x1, 2);
 	
 	cairo_destroy (cr);
@@ -925,6 +1022,9 @@ clearlooks_style_draw_shadow_gap (DRAW_ARGS,
 	const ClearlooksColors *colors;
 	cairo_t *cr;
 
+	CHECK_ARGS
+	SANITIZE_SIZE
+
 	cr     = ge_gdk_drawable_to_cairo (window, area);
 	colors = &clearlooks_style->colors;
 	
@@ -937,11 +1037,11 @@ clearlooks_style_draw_shadow_gap (DRAW_ARGS,
 		frame.gap_side  = gap_side;
 		frame.gap_x     = gap_x;
 		frame.gap_width = gap_width;
-		frame.border    = (CairoColor*)&colors->shade[5];
+		frame.border    = &colors->shade[5];
 		
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
 
-		params.corners = CR_CORNER_NONE;
+		params.corners = CR_CORNER_ALL;
 		
 		STYLE_FUNCTION(draw_frame) (cr, colors, &params, &frame,
 		                       x, y, width, height);
@@ -971,18 +1071,17 @@ clearlooks_style_draw_resize_grip (GtkStyle       *style,
 {
 	ClearlooksStyle *clearlooks_style = CLEARLOOKS_STYLE (style);
 	ClearlooksColors *colors = &clearlooks_style->colors;
-
 	cairo_t *cr;
-
 	WidgetParameters params;
 	ResizeGripParameters grip;
+
+	CHECK_ARGS
+	SANITIZE_SIZE
+
 	grip.edge = (ClearlooksWindowEdge)edge;
 
 	g_return_if_fail (window != NULL);
 
-	if (edge != GDK_WINDOW_EDGE_SOUTH_EAST)
-		return; /* sorry... need to work on this :P */
-	
 	cr = ge_gdk_drawable_to_cairo (window, area);
 
 	clearlooks_set_widget_parameters (widget, style, state_type, &params);	
@@ -991,8 +1090,6 @@ clearlooks_style_draw_resize_grip (GtkStyle       *style,
 	                             x, y, width, height);
 
 	cairo_destroy (cr);
-
-	return;
 }
 
 static void
@@ -1002,8 +1099,12 @@ clearlooks_style_draw_tab (DRAW_ARGS)
 	ClearlooksColors *colors = &clearlooks_style->colors;
 	WidgetParameters params;
 	ArrowParameters  arrow; 	 
+	cairo_t *cr;
 
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+	CHECK_ARGS
+	SANITIZE_SIZE
+	
+	cr = ge_gdk_drawable_to_cairo (window, area);
 
 	clearlooks_set_widget_parameters (widget, style, state_type, &params);
 	arrow.type      = CL_ARROW_COMBO;
@@ -1031,41 +1132,40 @@ clearlooks_style_draw_arrow (GtkStyle  *style,
 {
 	ClearlooksStyle  *clearlooks_style = CLEARLOOKS_STYLE (style);
 	ClearlooksColors *colors = &clearlooks_style->colors;
+	WidgetParameters params;
+	ArrowParameters  arrow;
 	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
-		
+
+	CHECK_ARGS
 	SANITIZE_SIZE
 
-  if (arrow_type == (GtkArrowType)4) { /* NONE - new in GTK 2.10 */
+	if (arrow_type == GTK_ARROW_NONE) {
 		cairo_destroy (cr);
 		return;
 	}
 
-	if (DETAIL ("arrow"))
+	clearlooks_set_widget_parameters (widget, style, state_type, &params);
+	arrow.type = CL_ARROW_NORMAL;
+	arrow.direction = (ClearlooksDirection)arrow_type;
+	
+	if (ge_is_combo_box (widget, FALSE) && !ge_is_combo_box_entry (widget))
 	{
-		WidgetParameters params;
-		ArrowParameters  arrow;
-		
-		clearlooks_set_widget_parameters (widget, style, state_type, &params);
-		arrow.type = CL_ARROW_NORMAL;
-		arrow.direction = (ClearlooksDirection)arrow_type;
-			
-    if (ge_is_combo_box (widget, FALSE) && !ge_is_combo_box_entry (widget)) 	 
-    { 	 
-            arrow.type = CL_ARROW_COMBO; 	 
-            y -= 2; 	 
-            height += 4; 	 
-            x += 1; 	 
-    }
-		
-		STYLE_FUNCTION(draw_arrow) (cr, colors, &params, &arrow, x, y, width, height);
+		arrow.type = CL_ARROW_COMBO;
 	}
-	else
+	
+	/* I have no idea why, but the arrow of GtkCombo is larger than in other places.
+	 * Subtracting 3 seems to fix this. */
+	if (widget && widget->parent && GE_IS_COMBO (widget->parent->parent))
 	{
-		clearlooks_parent_class->draw_arrow (style, window, state_type, shadow, area,
-		                          widget, detail, arrow_type, fill,
-		                          x, y, width, height);
+		if (params.ltr)
+			x += 1;
+		else
+			x += 2;
+		width -= 3;
 	}
 	
+	STYLE_FUNCTION(draw_arrow) (cr, colors, &params, &arrow, x, y, width, height);
+	
 	cairo_destroy (cr);
 }
 
@@ -1119,6 +1219,7 @@ clearlooks_style_realize (GtkStyle * style)
 	
 	for (i=0; i<5; i++)
 	{
+		ge_gdk_color_to_cairo (&style->fg[i], &clearlooks_style->colors.fg[i]);
 		ge_gdk_color_to_cairo (&style->bg[i], &clearlooks_style->colors.bg[i]);
 		ge_gdk_color_to_cairo (&style->base[i], &clearlooks_style->colors.base[i]);
 		ge_gdk_color_to_cairo (&style->text[i], &clearlooks_style->colors.text[i]);
@@ -1239,6 +1340,7 @@ clearlooks_style_copy (GtkStyle * style, GtkStyle * src)
 	cl_style->has_scrollbar_color = cl_src->has_scrollbar_color;
 	cl_style->animation           = cl_src->animation;
 	cl_style->radius              = cl_src->radius;
+	cl_style->style               = cl_src->style;
 	
 	clearlooks_parent_class->copy (style, src);
 }
@@ -1298,6 +1400,54 @@ scale_or_ref (GdkPixbuf *src,
 	}
 }
 
+static void
+clearlooks_style_draw_layout (GtkStyle * style,
+	     GdkWindow * window,
+	     GtkStateType state_type,
+	     gboolean use_text,
+	     GdkRectangle * area,
+	     GtkWidget * widget,
+	     const gchar * detail, gint x, gint y, PangoLayout * layout)
+{
+  GdkGC *gc;
+
+  g_return_if_fail (GTK_IS_STYLE (style));
+  g_return_if_fail (window != NULL);
+
+  gc = use_text ? style->text_gc[state_type] : style->fg_gc[state_type];
+
+  if (area)
+    gdk_gc_set_clip_rectangle (gc, area);
+
+  if (state_type == GTK_STATE_INSENSITIVE) {
+    ClearlooksStyle *clearlooks_style = CLEARLOOKS_STYLE (style);
+    ClearlooksColors *colors = &clearlooks_style->colors;
+
+    WidgetParameters params;
+
+    clearlooks_set_widget_parameters (widget, style, state_type, &params);
+
+    GdkColor etched;
+    CairoColor temp;
+
+    if (GTK_WIDGET_NO_WINDOW (widget))
+      ge_shade_color (&params.parentbg, 1.2, &temp);
+    else
+      ge_shade_color (&colors->bg[widget->state], 1.2, &temp);
+    etched.red = (int) (temp.r * 65535);
+    etched.green = (int) (temp.g * 65535);
+    etched.blue = (int) (temp.b * 65535);
+
+    gdk_draw_layout_with_colors (window, style->text_gc[state_type], x + 1, y + 1, layout, &etched, NULL);
+    gdk_draw_layout (window, style->text_gc[state_type], x, y, layout);
+  }
+  else
+    gdk_draw_layout (window, gc, x, y, layout);
+
+  if (area)
+    gdk_gc_set_clip_rectangle (gc, NULL);
+}
+
 static GdkPixbuf *
 clearlooks_style_draw_render_icon (GtkStyle            *style,
              const GtkIconSource *source,
@@ -1408,6 +1558,7 @@ clearlooks_style_class_init (ClearlooksStyleClass * klass)
 	style_class->draw_resize_grip = clearlooks_style_draw_resize_grip;
 	style_class->draw_tab         = clearlooks_style_draw_tab;
 	style_class->draw_arrow       = clearlooks_style_draw_arrow;
+	style_class->draw_layout      = clearlooks_style_draw_layout;
 	style_class->render_icon      = clearlooks_style_draw_render_icon;
 
 	clearlooks_register_style_classic (&clearlooks_style_class->style_functions[CL_STYLE_CLASSIC]);
@@ -1415,6 +1566,8 @@ clearlooks_style_class_init (ClearlooksStyleClass * klass)
 	clearlooks_register_style_glossy (&clearlooks_style_class->style_functions[CL_STYLE_GLOSSY]);
 	clearlooks_style_class->style_functions[CL_STYLE_INVERTED] = clearlooks_style_class->style_functions[CL_STYLE_CLASSIC];
 	clearlooks_register_style_inverted (&clearlooks_style_class->style_functions[CL_STYLE_INVERTED]);
+	clearlooks_style_class->style_functions[CL_STYLE_GUMMY] = clearlooks_style_class->style_functions[CL_STYLE_CLASSIC];
+	clearlooks_register_style_gummy (&clearlooks_style_class->style_functions[CL_STYLE_GUMMY]);
 }
 
 GType clearlooks_type_style = 0;
