@@ -47,18 +47,15 @@ clearlooks_get_parent_bg (const GtkWidget *widget, CairoColor *color)
 	GdkColor *gcolor;
 	
 	if (widget == NULL)
-	{
-		color->r = color->g = color->b = 255;
 		return;
-	}
 	
 	parent = widget->parent;
 	
-	while (parent && GTK_WIDGET_NO_WINDOW (parent))
+	while (parent && GTK_WIDGET_NO_WINDOW (parent) && !((GTK_IS_NOTEBOOK (parent)) || (GTK_IS_TOOLBAR (parent))))
 		parent = parent->parent;
 
 	if (parent == NULL)
-		parent = widget;
+		return;
 	
 	state_type = GTK_WIDGET_STATE (parent);
 	
@@ -76,7 +73,8 @@ clearlooks_scrollbar_get_stepper (GtkWidget    *widget,
 	GdkRectangle check_rectangle;
 	GtkOrientation orientation;
 
-	g_return_val_if_fail (GE_IS_RANGE (widget), CL_STEPPER_UNKNOWN);
+	if (!GE_IS_RANGE (widget))
+		return CL_STEPPER_UNKNOWN;
 
 	check_rectangle.x      = widget->allocation.x;
 	check_rectangle.y      = widget->allocation.y;
